@@ -166,6 +166,7 @@ static void test_nwrap_getpwnam_r(const char *name,
 		}
 		assert_true(ret);
 	}
+	assert_ptr_equal(&pwd, pwdp);
 
 	print_passwd(&pwd);
 
@@ -214,6 +215,7 @@ static bool test_nwrap_getpwuid_r(uid_t uid,
 		}
 		assert_true(ret);
 	}
+	assert_ptr_equal(&pwd, pwdp);
 
 	print_passwd(&pwd);
 
@@ -334,6 +336,7 @@ static bool test_nwrap_getgrnam_r(const char *name,
 		}
 		assert_true(ret);
 	}
+	assert_ptr_equal(&grp, grpp);
 
 	print_group(&grp);
 
@@ -384,6 +387,7 @@ static bool test_nwrap_getgrgid_r(gid_t gid,
 		}
 		assert_true(ret);
 	}
+	assert_ptr_equal(&grp, grpp);
 
 	print_group(&grp);
 
@@ -433,9 +437,11 @@ static bool test_nwrap_enum_passwd(struct passwd **pwd_array_p,
 static bool test_nwrap_enum_r_passwd(struct passwd **pwd_array_p,
 				     size_t *num_pwd_p)
 {
-	struct passwd pwd, *pwdp;
 	struct passwd *pwd_array = NULL;
 	size_t num_pwd = 0;
+/* Skip these tests if the platform does not provide getpwent_r() */
+#ifdef HAVE_GETPWENT_R
+	struct passwd pwd, *pwdp;
 	char buffer[4096];
 	int ret;
 
@@ -450,7 +456,7 @@ static bool test_nwrap_enum_r_passwd(struct passwd **pwd_array_p,
 		if (pwdp == NULL) {
 			break;
 		}
-#else
+#else /* HAVE_SOLARIS_GETPWENT_R */
 		ret = getpwent_r(&pwd, buffer, sizeof(buffer), &pwdp);
 		if (ret != 0) {
 			if (ret != ENOENT) {
@@ -458,7 +464,7 @@ static bool test_nwrap_enum_r_passwd(struct passwd **pwd_array_p,
 			}
 			break;
 		}
-#endif
+#endif /* HAVE_SOLARIS_GETPWENT_R */
 		print_passwd(&pwd);
 		if (pwd_array_p && num_pwd_p) {
 			pwd_array = realloc(pwd_array, sizeof(struct passwd) * (num_pwd + 1));
@@ -470,6 +476,7 @@ static bool test_nwrap_enum_r_passwd(struct passwd **pwd_array_p,
 
 	DEBUG("Testing endpwent\n");
 	endpwent();
+#endif /* HAVE_GETPWENT_R */
 
 	if (pwd_array_p) {
 		*pwd_array_p = pwd_array;
@@ -598,9 +605,11 @@ static bool test_nwrap_enum_group(struct group **grp_array_p,
 static bool test_nwrap_enum_r_group(struct group **grp_array_p,
 				    size_t *num_grp_p)
 {
-	struct group grp, *grpp;
 	struct group *grp_array = NULL;
 	size_t num_grp = 0;
+/* Skip these tests if the platform does not provide getgrent_r() */
+#ifdef HAVE_GETGRENT_R
+	struct group grp, *grpp;
 	char buffer[4096];
 	int ret;
 
@@ -615,7 +624,7 @@ static bool test_nwrap_enum_r_group(struct group **grp_array_p,
 		if (grpp == NULL) {
 			break;
 		}
-#else
+#else /* HAVE_SOLARIS_GETGRENT_R */
 		ret = getgrent_r(&grp, buffer, sizeof(buffer), &grpp);
 		if (ret != 0) {
 			if (ret != ENOENT) {
@@ -623,7 +632,7 @@ static bool test_nwrap_enum_r_group(struct group **grp_array_p,
 			}
 			break;
 		}
-#endif
+#endif /* HAVE_SOLARIS_GETGRENT_R */
 		print_group(&grp);
 		if (grp_array_p && num_grp_p) {
 			grp_array = realloc(grp_array, sizeof(struct group) * (num_grp + 1));
@@ -635,6 +644,7 @@ static bool test_nwrap_enum_r_group(struct group **grp_array_p,
 
 	DEBUG("Testing endgrent\n");
 	endgrent();
+#endif /* HAVE_GETGRENT_R */
 
 	if (grp_array_p) {
 		*grp_array_p = grp_array;
@@ -802,8 +812,10 @@ static bool test_nwrap_membership_user(const struct passwd *pwd,
 		struct group grp = grp_array[i];
 
 		if (test_nwrap_user_in_group(pwd, &grp)) {
+			struct group current_grp = {
+				.gr_name = NULL,
+			};
 
-			struct group current_grp;
 			num_user_groups_from_enum++;
 
 			test_nwrap_getgrnam(grp.gr_name, &current_grp);
